##  Subscription Type
The subscription type outlines the level of responsibility a user has regarding a fact sheet in SAP LeanIX. It categorizes how fact sheet subscribers interact with and manage the fact sheet data and they are predefined and nonconfigurable. Subscription type can be one of the following types:
  * Responsible: Subscribers of this type are responsible for keeping the fact sheet up-to-date and accurate. They actively add and update information in the fact sheet. There can be multiple responsible subscribers for a fact sheet.
  * Accountable: Accountable subscribers have overall accountability for the fact sheet, and they typically also handle business responsibilities associated with fact sheets. Only one user can be ‘Accountable’ per fact sheet, ensuring clear ownership.


  * Observer: Observers are notified and kept informed about changes to the fact sheet. They can also participate in surveys, but they are not responsible for maintaining the data.
